#!/bin/bash -p

# Copyright(c) 2011 VMware, Inc. All rights reserved.
# Script to delete an SMB share and the shared folder
# Usage: rmshare.sh SHARENAME SHAREPATH
#
# Prerequisites:
#   -- sharename must not contain spaces

###
### Function to exit with an error message.
###
fail() {
   echo $1
   exit 1
}

###
### Script starts here.
###

###
### This executable runs with root privileges, so hardcode a PATH where
### unprivileged users cannot write.
###
export PATH=/bin:/sbin:/usr/bin:/usr/sbin

if [ $# -ne 2 ]; then fail "Usage: $0 SHARENAME SHAREPATH"; fi
if [ $UID -ne 0 ]; then fail "Please run $0 as root."; fi

SHARENAME=$1
SHAREPATH=$2

echo $SHARENAME | egrep -q '[[:space:]]' && fail "Error: sharename must not contain spaces or tabs."
if [ "$SHAREPATH" == "" ]; then fail "Usage: $0 SHARENAME SHAREPATH"; fi

dscl localhost -delete /Local/Default/SharePoints/$SHARENAME || fail "Failed to remove share $SHARENAME"

#
# On Snow Leopard, synchronize_shares is needed to persist the dscl changes to the SAMBA files.
#

if [ -f /usr/libexec/samba/synchronize-shares ]; then
   /usr/libexec/samba/synchronize-shares || fail "Unable to synchronize sharing info to SAMBA"
fi

rm -rf "$SHAREPATH"
