#!/bin/bash -p

# Copyright(c) 2011 VMware, Inc. All rights reserved.
# Script to delete a user
# Usage: rmuser.sh USERNAME
#
# Prerequisites:
#   -- username must not contain spaces

###
### Function to exit with an error message.
###
fail() {
   echo $1
   exit 1
}

###
### Script starts here.
###

###
### This executable runs with root privileges, so hardcode a PATH where
### unprivileged users cannot write.
###
export PATH=/bin:/sbin:/usr/bin:/usr/sbin

if [ $# -ne 1 ]; then fail "Usage: $0 USERNAME"; fi
if [ $UID -ne 0 ]; then fail "Please run $0 as root."; fi

USERNAME=$1

if [ "$USERNAME" == "" ]; then fail "Usage: $0 USERNAME"; fi
echo $USERNAME | egrep -q '[[:space:]]' && fail "Error: username must not contain spaces or tabs."

###
### Disable Windows Sharing for this user.
### Remove the home directory.
### Delete the user.
###

pwpolicy -u $USERNAME -sethashtypes SMB-NT off || echo "pwpolicy failed to disable Windows sharing for $USERNAME"
rm -rf /Users/$USERNAME || echo "Unable to delete user home directory /Users/$USERNAME"
dscl . -delete /Users/$USERNAME || fail "dscl failed to delete user /Users/$USERNAME"


